@@ -62,7 +62,9 @@
 #' Using `drop = c('fitted', 'log_lik', 'alpha_re', 'x_true')` is equivalent to `slim = TRUE`. Note that if `slim = TRUE`, then `drop` will be ignored---so only use one or the other.
 #' @param control A named list of parameters to control the sampler's behavior. See \code{\link[rstan]{stan}} for details. 
 #' 
-#' @param ... Other arguments passed to \code{\link[rstan]{sampling}}. 
+#' @param ... Other arguments passed to \code{\link[rstan]{sampling}}.
+#'
+#' @param quiet Controls (most) automatic printing to the console. By default, any prior distributions that have not been assigned by the user are printed to the console. If `quiet = TRUE`, these will not be printed. Using `quiet = TRUE` will also force `refresh = 0`.
 #' 
 #' @details
 #'
@@ -239,6 +241,7 @@ stan_sar <- function(formula,
                      slim = FALSE,
                      drop = NULL,
                      control = NULL,
+                     quiet = FALSE,                     
                      ...
                      ) {
     stopifnot(inherits(formula, "formula"))
@@ -248,6 +251,9 @@ stan_sar <- function(formula,
     stopifnot(!missing(data))
     check_sar_parts(sar_parts)
     stopifnot(sar_parts$n == nrow(data))
+    # silence?
+    if (quiet) refresh <- 0
+    # C
     if (!missing(C)) {
         stopifnot(inherits(C, "Matrix") | inherits(C, "matrix"))
         stopifnot(all(dim(C) == nrow(data)))
@@ -409,7 +415,7 @@ stan_sar <- function(formula,
     ## PARAMETERS TO KEEP, with SAR PARAMETERS [STOP] -------------
     if (me.list$has_me) priors_made_slim$ME_model <- ME$prior    
     ## PRINT PRIORS  -------------
-    print_priors(prior, priors_made_slim)
+    if (!quiet) print_priors(prior, priors_made_slim)
     ## MCMC INITIAL VALUES -------------
     inits <- "random"
     if (censor_point > 0 | (standata$has_me == 1 && any(standata$use_logit == 1))) {
